Type Definition lexical_write_float::options::OptionUsize
source · [−]pub type OptionUsize = Option<NonZeroUsize>;Expand description
Type with the exact same size as a usize.
pub type OptionUsize = Option<NonZeroUsize>;Type with the exact same size as a usize.